# Barcode Generation & Scanning API for C++


![Nuget](https://img.shields.io/nuget/v/Aspose.BarCode.Cpp) ![Nuget](https://img.shields.io/nuget/dt/Aspose.Barcode.Cpp)

[![banner](https://raw.githubusercontent.com/Aspose/aspose.github.io/master/img/banners/aspose_barcode-for-cpp-banner.png)](https://downloads.aspose.com/barcode/cpp)

[Product Page](https://products.aspose.com/barcode/cpp/) | [Docs](https://docs.aspose.com/barcode/cpp/) | [Demos](https://products.aspose.app/barcode/family) | [API Reference](https://reference.aspose.com/barcode/cpp) | [Examples](https://github.com/aspose-barcode/Aspose.Barcode-for-C) | [Blog](https://blog.aspose.com/category/barcode/) | [Search](https://search.aspose.com/) | [Free Support](https://forum.aspose.com/c/barcode) | [Temporary License](https://purchase.aspose.com/temporary-license/)

[Aspose.BarCode for C++](https://products.aspose.com/barcode/cpp/) enables the developers to generate, scan, and manipulate barcodes from within their own C++ applications. C++ Barcode Library allows you to modify and customize barcode properties including font, foreground & background colors, alignment, barcode label location, and barcode caption.

## What is Aspose.BarCode for C++?

Aspose.BarCode for C++ is an on premise API to add the functionality of barcode scanning, recognition, generation, and conversion to your existing or new C++ applications. Aspose.BarCode has the capability to work with 40+ different barcode symbologies without requiring any 3rd party software installation. Aspose.BarCode for C++ supports barcodes of various file formats such as, JPEG, SVG, PNG, EMF, EXIF, etc. Along with generating high-quality numeric, alpha-numeric and 2D barcodes, you can also customize and control the appearance of the generated barcodes; such as, CodeText, captions, dimensions, aspect ratio, and more. Apply checksum validation on specific symbologies.

Aspose.BarCode for C++ also assists you in scanning, reading and recognizing barcodes in an efficient manner via multi-threading. It can recognize barcode symbologies and fetch the CodeText. You can also detect multiple symbologies present in a single picture or perform barcode recognition on a page with mixed text and images.

Aspose.BarCode for C++ is completely written in C++ and exposes a simple set of C++ classes that allow you to create barcodes at the backend, while also providing GUI based controls to display barcodes in Windows Forms and Web Forms.

## Barcode Generation Features

- [Generate barcode](https://docs.aspose.com/barcode/cpp/generate-barcodes-with-aspose-barcode-apis/) images programmatically.
- [Create a `PDF417` Barcode](https://docs.aspose.com/barcode/cpp/pdf417-and-macropdf417-barcode/), set error correction level, and compaction mode.
- Generate multiple `MacroPdf417` barcodes.
- Create `C40` or Text encoded [Datamatrix barcodes](https://docs.aspose.com/barcode/cpp/datamatrix-barcode/) with default or custom encoding mode.
- Create QR and MicroQR barcodes and perform encoding.
- Supports error correction for various types of barcodes.
- Generate barcodes with a logo or other images inside instead of CodeText.
- Hide CodeText that is too long or reduce the font size of CodeText.
- Adjust image size of 2D barcodes and set aspect ratio.
- Detect Unicode encoding of barcodes.
- CodeText can be set as per the associated symbology type and the outbound part is truncated.
- Enable image border, modify barcode image border width and style.
- Option to colorize barcode, code text, barcode background, barcode border, and caption.
- Specify size unit for the barcode image in document, inch, millimeter, pixel, and point.
- Enable checksum for the barcodes of applicable symbologies.
- Lots of other barcode processing features.

## Supported Symbologies for Barcode Generation & Recognition

- BarCode Supplement
- BooklandEAN
- Codabar
- Code11
- Code128
- Code39 Extended
- Code39 Standard
- Code93 Extended
- Code93 Standard
- Datamatrix
- Deutsche Post Identcode
- EAN128
- EAN13
- EAN14(SCC14)
- EAN8
- Interleaved2of5
- ITF14
- Matrix 2 of 5
- MSI
- PDF417
- Planet
- Postnet
- PZN (Pharma Zentral Nummer, Pharmazentralnummer barcode)
- QR
- SSCC18
- Standard2of5
- UPCA
- UPCE

## Supported Symbologies for Barcode Generation Only

- Australia Post
- Aztec

## Read & Write Barcode Labels

JPEG, TIFF, PNG, BMP, GIF, EXIF

## Save Barcode Labels As

EMF, SVG

## Generate Code128 Barcode in PNG Format

You can execute the below code snippet to see how Aspose.BarCode API works in your development environment. You may also check the [GitHub Repository](https://github.com/aspose-barcode/Aspose.Barcode-for-C) for other common usage scenarios.

```c++
// instantiate barcode object and set CodeText & Barcode Symbology
System::SharedPtr<BarcodeGenerator> generator
    = System::MakeObject<BarcodeGenerator>(EncodeTypes::Code128, u"1234");
generator->Save(dir + u"output.png");
```

## Hide Barcode Label Text using C++

Aspose.BarCode for C++ allows you to customize various properties of barcodes, such as borders, color, type, bar height as well as barcode text. The following example shows, how simple it is to hide the barcode text using C++:

```c++
System::String codeText = System::String(u"The quick brown fox jumps over the lazy dog\n")
    + u"The quick brown fox jumps over the lazy dog\n";

// instantiate barcode object and set CodeText, Symbology , and  CodeLocation
System::SharedPtr<BarcodeGenerator> generator = [&]
{
    auto tmp_0 = System::MakeObject<BarcodeGenerator>(EncodeTypes::DataMatrix, codeText);

    tmp_0->get_Parameters()->get_Barcode()->get_CodeTextParameters()->set_Location(
        CodeLocation::None);
    return tmp_0;
}();
generator->Save(dir + u"output.png", BarCodeImageFormat::Png);
```

[Product Page](https://products.aspose.com/barcode/cpp/) | [Docs](https://docs.aspose.com/barcode/cpp/) | [Demos](https://products.aspose.app/barcode/family) | [API Reference](https://reference.aspose.com/barcode/cpp) | [Examples](https://github.com/aspose-barcode/Aspose.Barcode-for-C) | [Blog](https://blog.aspose.com/category/barcode/) | [Search](https://search.aspose.com/) | [Free Support](https://forum.aspose.com/c/barcode) | [Temporary License](https://purchase.aspose.com/temporary-license/)
