#pragma once
//Copyright(c) 2001-2024 Aspose Pty Ltd.All rights reserved.

#include <system/idisposable.h>
#include <system/array.h>
#include <cstdint>

#include "aspose_barcode_api_defs.h"

namespace Aspose
{
namespace BarCode
{
namespace Drawing
{
class TextMeasurer;
} // namespace Drawing
namespace Generation
{
enum class BarCodeImageFormat;
class BaseEncodeType;
class BaseGenerationParameters;
class BaseRenderer;
} // namespace Generation
class VentureLicenser;
} // namespace BarCode
} // namespace Aspose
namespace System
{
namespace Drawing
{
class Bitmap;
} // namespace Drawing
namespace IO
{
class Stream;
} // namespace IO
namespace Text
{
class Encoding;
} // namespace Text
} // namespace System

namespace Aspose {

namespace BarCode {

namespace Generation {

class ASPOSE_BARCODE_SHARED_CLASS BarcodeGenerator final : public System::IDisposable
{
    typedef BarcodeGenerator ThisType;
    typedef System::IDisposable BaseType;
    
    typedef ::System::BaseTypesInfo<BaseType> ThisTypeBaseTypesInfo;
    ASPOSE_BARCODE_SHARED_RTTI_INFO_DECL();
    
    friend class Aspose::BarCode::VentureLicenser;
    
public:

    ASPOSE_BARCODE_SHARED_API System::SharedPtr<BaseGenerationParameters> get_Parameters() const;
    ASPOSE_BARCODE_SHARED_API System::SharedPtr<BaseEncodeType> get_BarcodeType();
    ASPOSE_BARCODE_SHARED_API void set_BarcodeType(System::SharedPtr<BaseEncodeType> value);
    ASPOSE_BARCODE_SHARED_API System::String get_CodeText();
    ASPOSE_BARCODE_SHARED_API void set_CodeText(System::String value);
    
    ASPOSE_BARCODE_SHARED_API BarcodeGenerator(System::SharedPtr<BaseEncodeType> type);
    ASPOSE_BARCODE_SHARED_API BarcodeGenerator(System::SharedPtr<BaseEncodeType> type, System::String codeText);
    
    ASPOSE_BARCODE_SHARED_API void SetCodeText(System::ArrayPtr<uint8_t> codeBytes);
    ASPOSE_BARCODE_SHARED_API void SetCodeText(System::String codeText, System::SharedPtr<System::Text::Encoding> encoding);
    ASPOSE_BARCODE_SHARED_API void SetCodeText(System::String codeText, System::SharedPtr<System::Text::Encoding> encoding, bool insertBOM);
    ASPOSE_BARCODE_SHARED_API System::SharedPtr<System::Drawing::Bitmap> GenerateBarCodeImage();
    ASPOSE_BARCODE_SHARED_API void Save(System::SharedPtr<System::IO::Stream> stream, BarCodeImageFormat format);
    ASPOSE_BARCODE_SHARED_API void Save(System::String filename, BarCodeImageFormat format);
    ASPOSE_BARCODE_SHARED_API void Save(System::String filename);
    ASPOSE_BARCODE_SHARED_API bool ExportToXml(System::String xmlFile);
    ASPOSE_BARCODE_SHARED_API bool ExportToXml(System::SharedPtr<System::IO::Stream> xml);
    static ASPOSE_BARCODE_SHARED_API System::SharedPtr<BarcodeGenerator> ImportFromXml(System::String xmlFile);
    static ASPOSE_BARCODE_SHARED_API System::SharedPtr<BarcodeGenerator> ImportFromXml(System::SharedPtr<System::IO::Stream> xml);
    ASPOSE_BARCODE_SHARED_API void Dispose() override;
    
protected:

    void SetVentureLicense(System::SharedPtr<System::Object> ventureLicense);
    
    virtual ASPOSE_BARCODE_SHARED_API ~BarcodeGenerator();
    
    #ifdef ASPOSE_GET_SHARED_MEMBERS
    ASPOSE_BARCODE_SHARED_API void GetSharedMembers(System::Object::shared_members_type& result) const override;
    #endif
    
    
private:

    System::SharedPtr<BaseGenerationParameters> _parameters;
    System::SharedPtr<Aspose::BarCode::Drawing::TextMeasurer> _textMeasurer;
    
    System::SharedPtr<BaseRenderer> createBaseRenderer(System::SharedPtr<BaseGenerationParameters> parameters);
    void insertWatermark(System::SharedPtr<BaseGenerationParameters> parameters);
    void initializeWithDefaultParameters();
    void DisposeAllResources();
    
};

} // namespace Generation
} // namespace BarCode
} // namespace Aspose


