#pragma once
// Copyright (c) 2001-2025 Aspose Pty Ltd. All Rights Reserved.

#include <system/object_ext.h>
#include <system/enum.h>
#include <drawing/color.h>
#include <cstdint>

#include "aspose_barcode_api_defs.h"

namespace Aspose
{
namespace BarCode
{
namespace Generation
{
class BarcodeParameters;
class BarcodeWithGuardsRenderer;
class BaseGenerationParameters;
class BaseRenderer;
class CMYKColor;
class CodetextRenderer;
class FontUnit;
class GS1CompositeBarRenderer;
namespace ParamsSpecification
{
class Code128ParamsSpecification;
class DotCodeParamsSpecification;
class EAN13ParamsSpecification;
class HanXinParamsSpecification;
class Interleaved2of5ParamsSpecification;
class ITF14ParamsSpecification;
class MaxiCodeParamsSpecification;
class PatchCodeParamsSpecification;
class SSCC18ParamsSpecification;
} // namespace ParamsSpecification
class RendererFactory;
class SimpleBarcodeRenderer;
enum class TextAlignment;
class Unit;
} // namespace Generation
namespace Serialization
{
namespace Xml
{
class CodetextParametersParser;
} // namespace Xml
} // namespace Serialization
} // namespace BarCode
} // namespace Aspose

namespace Aspose {

namespace BarCode {

namespace Generation {

enum class FontMode
{
    Auto = 0,
    Manual = 1
};

enum class CodeLocation
{
    Below = 0,
    Above = 1,
    None = 2
};

class ASPOSE_BARCODE_SHARED_CLASS CodetextParameters : public System::Object
{
    typedef CodetextParameters ThisType;
    typedef System::Object BaseType;
    
    typedef ::System::BaseTypesInfo<BaseType> ThisTypeBaseTypesInfo;
    ASPOSE_BARCODE_SHARED_RTTI_INFO_DECL();
    
    friend class Aspose::BarCode::Generation::BarcodeParameters;
    friend class Aspose::BarCode::Generation::ParamsSpecification::Code128ParamsSpecification;
    friend class Aspose::BarCode::Generation::ParamsSpecification::Interleaved2of5ParamsSpecification;
    friend class Aspose::BarCode::Generation::ParamsSpecification::DotCodeParamsSpecification;
    friend class Aspose::BarCode::Generation::ParamsSpecification::EAN13ParamsSpecification;
    friend class Aspose::BarCode::Generation::ParamsSpecification::HanXinParamsSpecification;
    friend class Aspose::BarCode::Generation::ParamsSpecification::ITF14ParamsSpecification;
    friend class Aspose::BarCode::Generation::ParamsSpecification::MaxiCodeParamsSpecification;
    friend class Aspose::BarCode::Generation::ParamsSpecification::PatchCodeParamsSpecification;
    friend class Aspose::BarCode::Generation::ParamsSpecification::SSCC18ParamsSpecification;
    friend class Aspose::BarCode::Generation::BaseGenerationParameters;
    friend class Aspose::BarCode::Generation::BarcodeWithGuardsRenderer;
    friend class Aspose::BarCode::Generation::SimpleBarcodeRenderer;
    friend class Aspose::BarCode::Generation::GS1CompositeBarRenderer;
    friend class Aspose::BarCode::Generation::BaseRenderer;
    friend class Aspose::BarCode::Generation::RendererFactory;
    friend class Aspose::BarCode::Generation::CodetextRenderer;
    friend class Aspose::BarCode::Serialization::Xml::CodetextParametersParser;
    
public:

    ASPOSE_BARCODE_SHARED_API System::String get_TwoDDisplayText() const;
    ASPOSE_BARCODE_SHARED_API void set_TwoDDisplayText(System::String value);
    ASPOSE_BARCODE_SHARED_API Aspose::BarCode::Generation::FontMode get_FontMode() const;
    ASPOSE_BARCODE_SHARED_API void set_FontMode(Aspose::BarCode::Generation::FontMode value);
    ASPOSE_BARCODE_SHARED_API System::SharedPtr<FontUnit> get_Font() const;
    ASPOSE_BARCODE_SHARED_API System::SharedPtr<Unit> get_Space() const;
    ASPOSE_BARCODE_SHARED_API void set_Space(System::SharedPtr<Unit> value);
    ASPOSE_BARCODE_SHARED_API TextAlignment get_Alignment() const;
    ASPOSE_BARCODE_SHARED_API void set_Alignment(TextAlignment value);
    ASPOSE_BARCODE_SHARED_API System::Drawing::Color get_Color() const;
    ASPOSE_BARCODE_SHARED_API void set_Color(System::Drawing::Color value);
    ASPOSE_BARCODE_SHARED_API CodeLocation get_Location() const;
    ASPOSE_BARCODE_SHARED_API void set_Location(CodeLocation value);
    ASPOSE_BARCODE_SHARED_API bool get_NoWrap() const;
    ASPOSE_BARCODE_SHARED_API void set_NoWrap(bool value);
    
    ASPOSE_BARCODE_SHARED_API System::String ToString() const override;
    
protected:

    ASPOSE_BARCODE_SHARED_API void set_Font(System::SharedPtr<FontUnit> value);
    System::SharedPtr<Aspose::BarCode::Generation::CMYKColor> get_CMYKColor() const;
    void set_CMYKColor(System::SharedPtr<Aspose::BarCode::Generation::CMYKColor> value);
    System::Drawing::Color get_BackColor() const;
    void set_BackColor(System::Drawing::Color value);
    System::SharedPtr<Aspose::BarCode::Generation::CMYKColor> get_CMYKBackColor() const;
    void set_CMYKBackColor(System::SharedPtr<Aspose::BarCode::Generation::CMYKColor> value);
    System::String get_Checksum() const;
    void set_Checksum(System::String value);
    
    static const float CodetextMaxHeightPercent;
    
    CodetextParameters();
    
    MEMBER_FUNCTION_MAKE_OBJECT_DECLARATION(CodetextParameters, CODEPORTING_ARGS());
    int32_t GetStateHash();
    #ifdef ASPOSE_GET_SHARED_MEMBERS
    ASPOSE_BARCODE_SHARED_API void GetSharedMembers(System::Object::shared_members_type& result) const override;
    #endif
    
    
private:

    System::String pr_TwoDDisplayText;
    Aspose::BarCode::Generation::FontMode pr_FontMode;
    System::SharedPtr<FontUnit> pr_Font;
    System::SharedPtr<Unit> pr_Space;
    TextAlignment pr_Alignment;
    System::Drawing::Color pr_Color;
    System::SharedPtr<Aspose::BarCode::Generation::CMYKColor> pr_CMYKColor;
    System::Drawing::Color pr_BackColor;
    System::SharedPtr<Aspose::BarCode::Generation::CMYKColor> pr_CMYKBackColor;
    CodeLocation pr_Location;
    bool pr_NoWrap;
    System::String pr_Checksum;
    
    System::String ToString_NonConst();
    
};

} // namespace Generation
} // namespace BarCode
} // namespace Aspose

template<>
struct EnumMetaInfo<Aspose::BarCode::Generation::FontMode>
{
    static const ASPOSE_BARCODE_SHARED_API std::array<std::pair<Aspose::BarCode::Generation::FontMode, const char_t*>, 2>& values();
};
template<>
struct EnumMetaInfo<Aspose::BarCode::Generation::CodeLocation>
{
    static const ASPOSE_BARCODE_SHARED_API std::array<std::pair<Aspose::BarCode::Generation::CodeLocation, const char_t*>, 3>& values();
};



