#pragma once

#include <system/object_ext.h>
#include <system/enum.h>
#include <system/array.h>
#include <cstdint>

#include "aspose_barcode_api_defs.h"

namespace Aspose
{
namespace BarCode
{
namespace Svm
{
class BinarySvmModel;
class IKernel;
} // namespace Svm
} // namespace BarCode
} // namespace Aspose
namespace System
{
namespace Collections
{
namespace Generic
{
template <typename, typename> class Dictionary;
template <typename> class List;
} // namespace Generic
} // namespace Collections
} // namespace System

namespace Aspose {

namespace BarCode {

namespace Svm {

enum class SvmDirection
{
    Horizontal,
    Vertical,
    Angle45,
    Angle135,
    Unknown
};

class ClassPair : public System::Object
{
    typedef ClassPair ThisType;
    typedef System::Object BaseType;
    
    typedef ::System::BaseTypesInfo<BaseType> ThisTypeBaseTypesInfo;
    RTTI_INFO_DECL();
    
public:

    int32_t Class1;
    int32_t Class2;
    
    ClassPair(int32_t class1, int32_t class2);
    
};

class MulticlassSvmModel : public System::Object
{
    typedef MulticlassSvmModel ThisType;
    typedef System::Object BaseType;
    
    typedef ::System::BaseTypesInfo<BaseType> ThisTypeBaseTypesInfo;
    RTTI_INFO_DECL();
    
public:

    int32_t get_NumberOfInputs() const;
    void set_NumberOfInputs(int32_t value);
    int32_t get_NumberOfClasses() const;
    void set_NumberOfClasses(int32_t value);
    
    System::SharedPtr<System::Collections::Generic::Dictionary<System::String, System::SharedPtr<BinarySvmModel>>> BinaryModels;
    
    System::SharedPtr<BinarySvmModel> GetByClassPair(System::SharedPtr<ClassPair> classPair);
    System::SharedPtr<BinarySvmModel> GetByClassPair(int32_t class1, int32_t class2);
    
    MulticlassSvmModel();
    
protected:

    #ifdef ASPOSE_GET_SHARED_MEMBERS
    void GetSharedMembers(System::Object::shared_members_type& result) const override;
    #endif
    
    
private:

    int32_t pr_NumberOfInputs;
    int32_t pr_NumberOfClasses;
    
};

class BinarySvmModel : public System::Object
{
    typedef BinarySvmModel ThisType;
    typedef System::Object BaseType;
    
    typedef ::System::BaseTypesInfo<BaseType> ThisTypeBaseTypesInfo;
    RTTI_INFO_DECL();
    
public:

    double get_Threshold() const;
    void set_Threshold(double value);
    double get_Weight() const;
    void set_Weight(double value);
    System::ArrayPtr<double> get_SupportVector() const;
    void set_SupportVector(System::ArrayPtr<double> value);
    System::SharedPtr<IKernel> get_Kernel() const;
    void set_Kernel(System::SharedPtr<IKernel> value);
    
    BinarySvmModel();
    
protected:

    #ifdef ASPOSE_GET_SHARED_MEMBERS
    void GetSharedMembers(System::Object::shared_members_type& result) const override;
    #endif
    
    
private:

    double pr_Threshold;
    double pr_Weight;
    System::ArrayPtr<double> pr_SupportVector;
    System::SharedPtr<IKernel> pr_Kernel;
    
};

class IAsposeSvm : public System::Object
{
    typedef IAsposeSvm ThisType;
    typedef System::Object BaseType;
    
    typedef ::System::BaseTypesInfo<BaseType> ThisTypeBaseTypesInfo;
    RTTI_INFO_DECL();
    
public:

    virtual System::ArrayPtr<double> LogLikelihood(System::SharedPtr<System::Collections::Generic::List<System::ArrayPtr<double>>> features, int32_t classIndex) = 0;
    
};

class AsposeSvm : public Aspose::BarCode::Svm::IAsposeSvm
{
    typedef AsposeSvm ThisType;
    typedef Aspose::BarCode::Svm::IAsposeSvm BaseType;
    
    typedef ::System::BaseTypesInfo<BaseType> ThisTypeBaseTypesInfo;
    RTTI_INFO_DECL();
    
public:

    AsposeSvm(System::SharedPtr<MulticlassSvmModel> model);
    
    System::ArrayPtr<double> LogLikelihood(System::SharedPtr<System::Collections::Generic::List<System::ArrayPtr<double>>> features, int32_t classIndex) override;
    System::ArrayPtr<double> LogLikelihood(System::ArrayPtr<System::ArrayPtr<double>> input, int32_t classIndex, System::ArrayPtr<double> result);
    double LogLikelihood(System::ArrayPtr<double> input, int32_t classIndex);
    System::ArrayPtr<double> Scores(System::ArrayPtr<double> input);
    System::ArrayPtr<double> Scores(System::ArrayPtr<double> input, System::ArrayPtr<double> result);
    
protected:

    #ifdef ASPOSE_GET_SHARED_MEMBERS
    void GetSharedMembers(System::Object::shared_members_type& result) const override;
    #endif
    
    
private:

    int32_t NumberOfClasses;
    int32_t NumberOfInputs;
    System::SharedPtr<MulticlassSvmModel> Model;
    
    System::ArrayPtr<double> distanceByElimination(System::ArrayPtr<double> input, System::ArrayPtr<double> result);
    
};

} // namespace Svm
} // namespace BarCode
} // namespace Aspose

template<>
struct EnumMetaInfo<Aspose::BarCode::Svm::SvmDirection>
{
    static const ASPOSE_BARCODE_SHARED_API std::array<std::pair<Aspose::BarCode::Svm::SvmDirection, const char_t*>, 5>& values();
};



