#pragma once

#include <system/object_ext.h>
#include <system/enum.h>
#include <system/array.h>
#include <cstdint>

#include "aspose_barcode_api_defs.h"

namespace Aspose
{
namespace BarCode
{
namespace Common
{
namespace Bitmaps
{
class ByteBitmap;
class FloatBitmap;
} // namespace Bitmaps
} // namespace Common
} // namespace BarCode
} // namespace Aspose

namespace Aspose {

namespace BarCode {

namespace BarCodeRecognition {

namespace BarGrdDetector {

enum class GradientDirection
{
    Horizontal = 0,
    Angle45 = 1,
    Vertical = 2,
    Angle135 = 3,
    Unknown = 4
};

class GradientDirectionExt
{
    typedef GradientDirectionExt ThisType;
    
public:

    static GradientDirection GetOrtogonal(GradientDirection dir);
    
public:
    GradientDirectionExt() = delete;
};

class GradientMetrics : public System::Object
{
    typedef GradientMetrics ThisType;
    typedef System::Object BaseType;
    
    typedef ::System::BaseTypesInfo<BaseType> ThisTypeBaseTypesInfo;
    RTTI_INFO_DECL();
    
public:

    int32_t get_Width() const;
    int32_t get_Height() const;
    int32_t get_TileSize() const;
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> get_HorizontalGradientPowerByTile() const;
    void set_HorizontalGradientPowerByTile(System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> value);
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> get_VerticalGradientPowerByTile() const;
    void set_VerticalGradientPowerByTile(System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> value);
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> get_Angle45GradientPowerByTile() const;
    void set_Angle45GradientPowerByTile(System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> value);
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> get_Angle135GradientPowerByTile() const;
    void set_Angle135GradientPowerByTile(System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> value);
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> get_MaxGradientPower() const;
    void set_MaxGradientPower(System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> value);
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> get_SecondaryGradientPower() const;
    void set_SecondaryGradientPower(System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> value);
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::ByteBitmap> get_SelectedGrd() const;
    void set_SelectedGrd(System::SharedPtr<Aspose::BarCode::Common::Bitmaps::ByteBitmap> value);
    System::ArrayPtr<GradientDirection> get_MainGradientDirectionByTile() const;
    System::ArrayPtr<GradientDirection> get_SecondaryGradientDirectionByTile() const;
    
    GradientMetrics(int32_t width, int32_t height, int32_t tileSize);
    
    virtual void ClearPoint(int32_t x, int32_t y);
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> GetMapByDirection(GradientDirection gradientDirection);
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> GetMapByDirection(int32_t gradientDirection);
    GradientDirection GetMainGradientDirectionByTile(int32_t x, int32_t y);
    GradientDirection GetSecondaryGradientDirectionByTile(int32_t x, int32_t y);
    void CalculateGradientDirectionMetrics();
    
protected:

    #ifdef ASPOSE_GET_SHARED_MEMBERS
    void GetSharedMembers(System::Object::shared_members_type& result) const override;
    #endif
    
    
private:

    int32_t pr_Width;
    
    void set_Width(int32_t value);
    
    int32_t pr_Height;
    
    void set_Height(int32_t value);
    
    int32_t pr_TileSize;
    
    void set_TileSize(int32_t value);
    
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> pr_HorizontalGradientPowerByTile;
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> pr_VerticalGradientPowerByTile;
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> pr_Angle45GradientPowerByTile;
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> pr_Angle135GradientPowerByTile;
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> pr_MaxGradientPower;
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> pr_SecondaryGradientPower;
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::ByteBitmap> pr_SelectedGrd;
    System::ArrayPtr<GradientDirection> pr_MainGradientDirectionByTile;
    
    void set_MainGradientDirectionByTile(System::ArrayPtr<GradientDirection> value);
    
    System::ArrayPtr<GradientDirection> pr_SecondaryGradientDirectionByTile;
    
    void set_SecondaryGradientDirectionByTile(System::ArrayPtr<GradientDirection> value);
    
};

class GradientEnergy : public Aspose::BarCode::BarCodeRecognition::BarGrdDetector::GradientMetrics
{
    typedef GradientEnergy ThisType;
    typedef Aspose::BarCode::BarCodeRecognition::BarGrdDetector::GradientMetrics BaseType;
    
    typedef ::System::BaseTypesInfo<BaseType> ThisTypeBaseTypesInfo;
    RTTI_INFO_DECL();
    
public:

    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> get_MainGradientPower() const;
    void set_MainGradientPower(System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> value);
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> get_BaseGradientPower() const;
    void set_BaseGradientPower(System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> value);
    
    GradientEnergy(int32_t width, int32_t height, int32_t tileSize);
    
protected:

    #ifdef ASPOSE_GET_SHARED_MEMBERS
    void GetSharedMembers(System::Object::shared_members_type& result) const override;
    #endif
    
    
private:

    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> pr_MainGradientPower;
    System::SharedPtr<Aspose::BarCode::Common::Bitmaps::FloatBitmap> pr_BaseGradientPower;
    
};

} // namespace BarGrdDetector
} // namespace BarCodeRecognition
} // namespace BarCode
} // namespace Aspose

template<>
struct EnumMetaInfo<Aspose::BarCode::BarCodeRecognition::BarGrdDetector::GradientDirection>
{
    static const ASPOSE_BARCODE_SHARED_API std::array<std::pair<Aspose::BarCode::BarCodeRecognition::BarGrdDetector::GradientDirection, const char_t*>, 5>& values();
};



