#pragma once
// Copyright (c) 2001-2024 Aspose Pty Ltd. All Rights Reserved.

#include <system/idisposable.h>
#include <system/array.h>
#include <cstdint>

#include "aspose_barcode_api_defs.h"

namespace Aspose
{
namespace BarCode
{
namespace BarCodeRecognition
{
class BarCodeReaderImplementation;
class BarCodeResult;
class BarcodeSettings;
class BaseDecodeType;
class QualitySettings;
class SingleDecodeType;
} // namespace BarCodeRecognition
namespace Common
{
class ProcessorSettings;
} // namespace Common
class VentureLicenser;
} // namespace BarCode
} // namespace Aspose
namespace System
{
namespace Drawing
{
class Bitmap;
class Rectangle;
} // namespace Drawing
namespace IO
{
class MemoryStream;
class Stream;
} // namespace IO
} // namespace System

namespace Aspose {

namespace BarCode {

namespace BarCodeRecognition {

class ASPOSE_BARCODE_SHARED_CLASS BarCodeReader : public System::IDisposable
{
    typedef BarCodeReader ThisType;
    typedef System::IDisposable BaseType;
    
    typedef ::System::BaseTypesInfo<BaseType> ThisTypeBaseTypesInfo;
    ASPOSE_BARCODE_SHARED_RTTI_INFO_DECL();
    
    friend class Aspose::BarCode::VentureLicenser;
    
public:

    static ASPOSE_BARCODE_SHARED_API System::SharedPtr<Aspose::BarCode::Common::ProcessorSettings> get_ProcessorSettings();
    ASPOSE_BARCODE_SHARED_API int32_t get_Timeout();
    ASPOSE_BARCODE_SHARED_API void set_Timeout(int32_t value);
    ASPOSE_BARCODE_SHARED_API System::ArrayPtr<System::SharedPtr<BarCodeResult>> get_FoundBarCodes() const;
    ASPOSE_BARCODE_SHARED_API int32_t get_FoundCount();
    ASPOSE_BARCODE_SHARED_API System::SharedPtr<Aspose::BarCode::BarCodeRecognition::QualitySettings> get_QualitySettings();
    ASPOSE_BARCODE_SHARED_API void set_QualitySettings(System::SharedPtr<Aspose::BarCode::BarCodeRecognition::QualitySettings> value);
    ASPOSE_BARCODE_SHARED_API System::SharedPtr<Aspose::BarCode::BarCodeRecognition::BarcodeSettings> get_BarcodeSettings() const;
    
    ASPOSE_BARCODE_SHARED_API void Abort();
    ASPOSE_BARCODE_SHARED_API System::ArrayPtr<System::SharedPtr<BarCodeResult>> ReadBarCodes();
    
    ASPOSE_BARCODE_SHARED_API BarCodeReader();
    
    ASPOSE_BARCODE_SHARED_API void SetBarCodeImage(System::SharedPtr<System::Drawing::Bitmap> value);
    ASPOSE_BARCODE_SHARED_API void SetBarCodeImage(System::SharedPtr<System::Drawing::Bitmap> value, System::ArrayPtr<System::Drawing::Rectangle> areas);
    ASPOSE_BARCODE_SHARED_API void SetBarCodeImage(System::SharedPtr<System::Drawing::Bitmap> value, System::Drawing::Rectangle area);
    ASPOSE_BARCODE_SHARED_API void SetBarCodeImage(System::String filename);
    ASPOSE_BARCODE_SHARED_API void SetBarCodeImage(System::SharedPtr<System::IO::Stream> stream);
    ASPOSE_BARCODE_SHARED_API void SetBarCodeReadType(const System::ArrayPtr<System::SharedPtr<SingleDecodeType>>& barcodeTypes);
    ASPOSE_BARCODE_SHARED_API void SetBarCodeReadType(System::SharedPtr<BaseDecodeType> type);
    
    ASPOSE_BARCODE_SHARED_API BarCodeReader(System::SharedPtr<System::Drawing::Bitmap> image);
    ASPOSE_BARCODE_SHARED_API BarCodeReader(System::SharedPtr<System::Drawing::Bitmap> image, const System::ArrayPtr<System::SharedPtr<BaseDecodeType>>& decodeTypes);
    ASPOSE_BARCODE_SHARED_API BarCodeReader(System::SharedPtr<System::Drawing::Bitmap> image, System::SharedPtr<BaseDecodeType> type);
    ASPOSE_BARCODE_SHARED_API BarCodeReader(System::SharedPtr<System::Drawing::Bitmap> image, System::Drawing::Rectangle area, const System::ArrayPtr<System::SharedPtr<BaseDecodeType>>& decodeTypes);
    ASPOSE_BARCODE_SHARED_API BarCodeReader(System::SharedPtr<System::Drawing::Bitmap> image, System::Drawing::Rectangle area, System::SharedPtr<BaseDecodeType> type);
    ASPOSE_BARCODE_SHARED_API BarCodeReader(System::SharedPtr<System::Drawing::Bitmap> image, System::ArrayPtr<System::Drawing::Rectangle> areas, const System::ArrayPtr<System::SharedPtr<BaseDecodeType>>& decodeTypes);
    ASPOSE_BARCODE_SHARED_API BarCodeReader(System::SharedPtr<System::Drawing::Bitmap> image, System::ArrayPtr<System::Drawing::Rectangle> areas, System::SharedPtr<BaseDecodeType> type);
    ASPOSE_BARCODE_SHARED_API BarCodeReader(System::String filename);
    ASPOSE_BARCODE_SHARED_API BarCodeReader(System::String filename, const System::ArrayPtr<System::SharedPtr<BaseDecodeType>>& decodeTypes);
    ASPOSE_BARCODE_SHARED_API BarCodeReader(System::String filename, System::SharedPtr<BaseDecodeType> type);
    ASPOSE_BARCODE_SHARED_API BarCodeReader(System::SharedPtr<System::IO::Stream> stream);
    ASPOSE_BARCODE_SHARED_API BarCodeReader(System::SharedPtr<System::IO::Stream> stream, System::SharedPtr<BaseDecodeType> type);
    ASPOSE_BARCODE_SHARED_API BarCodeReader(System::SharedPtr<System::IO::Stream> stream, const System::ArrayPtr<System::SharedPtr<BaseDecodeType>>& decodeTypes);
    
    ASPOSE_BARCODE_SHARED_API void Dispose() override;
    ASPOSE_BARCODE_SHARED_API bool ExportToXml(System::String xmlFile);
    ASPOSE_BARCODE_SHARED_API bool ExportToXml(System::SharedPtr<System::IO::Stream> xmlStream);
    static ASPOSE_BARCODE_SHARED_API System::SharedPtr<BarCodeReader> ImportFromXml(System::String xmlFile);
    static ASPOSE_BARCODE_SHARED_API System::SharedPtr<BarCodeReader> ImportFromXml(System::SharedPtr<System::IO::Stream> xmlStream);
    
protected:

    System::SharedPtr<BaseDecodeType> GetBarCodeDecodeType();
    void SetVentureLicense(System::SharedPtr<System::Object> ventureLicense);
    
    virtual ASPOSE_BARCODE_SHARED_API ~BarCodeReader();
    
    #ifdef ASPOSE_GET_SHARED_MEMBERS
    ASPOSE_BARCODE_SHARED_API void GetSharedMembers(System::Object::shared_members_type& result) const override;
    #endif
    
    
private:

    System::SharedPtr<BarCodeReaderImplementation> _readerImplementation;
    static System::SharedPtr<Aspose::BarCode::Common::ProcessorSettings> _processorSettings;
    
    static System::SharedPtr<System::IO::MemoryStream> ReadFileToMemoryStream(System::String fileName);
    static System::SharedPtr<System::IO::MemoryStream> ReadStreamToMemoryStream(System::SharedPtr<System::IO::Stream> str);
    static System::SharedPtr<System::Drawing::Bitmap> CopyBitmap(System::SharedPtr<System::Drawing::Bitmap> originalBitmap);
    void DisposeAllResources();
    
};

} // namespace BarCodeRecognition
} // namespace BarCode
} // namespace Aspose


