#pragma once

#include <system/object_ext.h>
#include <system/iequatable.h>
#include <system/enum.h>
#include <system/decimal.h>
#include <system/collections/list.h>
#include <system/array.h>
#include <cstdint>

#include "ComplexBarcode/ComplexCodetext/IComplexCodetext.h"
#include "aspose_barcode_api_defs.h"

namespace Aspose
{
namespace BarCode
{
namespace ComplexBarcode
{
class Address;
class AlternativeScheme;
class SwissQRBill;
} // namespace ComplexBarcode
namespace Generation
{
class BaseEncodeType;
} // namespace Generation
} // namespace BarCode
} // namespace Aspose
namespace System
{
namespace Globalization
{
class NumberFormatInfo;
} // namespace Globalization
namespace Text
{
class StringBuilder;
} // namespace Text
} // namespace System

namespace Aspose {

namespace BarCode {

namespace ComplexBarcode {

class ASPOSE_BARCODE_SHARED_CLASS SwissQRCodetext final : public Aspose::BarCode::ComplexBarcode::IComplexCodetext
{
    typedef SwissQRCodetext ThisType;
    typedef Aspose::BarCode::ComplexBarcode::IComplexCodetext BaseType;
    
    typedef ::System::BaseTypesInfo<BaseType> ThisTypeBaseTypesInfo;
    ASPOSE_BARCODE_SHARED_RTTI_INFO_DECL();
    
public:

    ASPOSE_BARCODE_SHARED_API System::SharedPtr<SwissQRBill> get_Bill() const;
    
    ASPOSE_BARCODE_SHARED_API SwissQRCodetext(System::SharedPtr<SwissQRBill> bill);
    ASPOSE_BARCODE_SHARED_API SwissQRCodetext();
    
    ASPOSE_BARCODE_SHARED_API System::String GetConstructedCodetext() override;
    ASPOSE_BARCODE_SHARED_API void InitFromString(System::String constructedCodetext) override;
    ASPOSE_BARCODE_SHARED_API System::SharedPtr<Aspose::BarCode::Generation::BaseEncodeType> GetBarcodeType() override;
    
protected:

    #ifdef ASPOSE_GET_SHARED_MEMBERS
    ASPOSE_BARCODE_SHARED_API void GetSharedMembers(System::Object::shared_members_type& result) const override;
    #endif
    
    
private:

    System::SharedPtr<SwissQRBill> _bill;
    static System::SharedPtr<System::Globalization::NumberFormatInfo> AmountNumberInfo;
    
    static void ValidateQRBill(System::SharedPtr<SwissQRBill> bill);
    void AppendPerson(System::SharedPtr<Address> address, System::SharedPtr<System::Text::StringBuilder> textBuilder);
    void AppendDataField(System::String value, System::SharedPtr<System::Text::StringBuilder> textBuilder);
    static bool IsValidAmount(System::Decimal amount);
    static System::String FormatAmountForCode(System::Decimal amount);
    static System::SharedPtr<System::Globalization::NumberFormatInfo> CreateAmountNumberInfo();
    static System::SharedPtr<Address> DecodeAddress(System::ArrayPtr<System::String> lines, int32_t startLine, bool isOptional);
    static System::ArrayPtr<System::String> SplitLines(System::String text);
    static void ThrowSingleValidationError(System::String msg = u"");
    
    static struct __StaticConstructor__ { __StaticConstructor__(); } s_constructor__;
    
};

class ASPOSE_BARCODE_SHARED_CLASS SwissQRBill final : public System::IEquatable<System::SharedPtr<Aspose::BarCode::ComplexBarcode::SwissQRBill>>
{
    typedef SwissQRBill ThisType;
    typedef System::IEquatable<System::SharedPtr<Aspose::BarCode::ComplexBarcode::SwissQRBill>> BaseType;
    
    typedef ::System::BaseTypesInfo<BaseType> ThisTypeBaseTypesInfo;
    ASPOSE_BARCODE_SHARED_RTTI_INFO_DECL();
    
    friend class Aspose::BarCode::ComplexBarcode::SwissQRCodetext;
    
public:

    enum class QrBillStandardVersion
    {
        V2_0
    };
    
    
public:

    ASPOSE_BARCODE_SHARED_API SwissQRBill::QrBillStandardVersion get_Version() const;
    ASPOSE_BARCODE_SHARED_API void set_Version(SwissQRBill::QrBillStandardVersion value);
    ASPOSE_BARCODE_SHARED_API System::Decimal get_Amount() const;
    ASPOSE_BARCODE_SHARED_API void set_Amount(System::Decimal value);
    ASPOSE_BARCODE_SHARED_API System::String get_Currency() const;
    ASPOSE_BARCODE_SHARED_API void set_Currency(System::String value);
    ASPOSE_BARCODE_SHARED_API System::String get_Account() const;
    ASPOSE_BARCODE_SHARED_API void set_Account(System::String value);
    ASPOSE_BARCODE_SHARED_API System::SharedPtr<Address> get_Creditor() const;
    ASPOSE_BARCODE_SHARED_API void set_Creditor(System::SharedPtr<Address> value);
    ASPOSE_BARCODE_SHARED_API System::String get_Reference() const;
    ASPOSE_BARCODE_SHARED_API void set_Reference(System::String value);
    ASPOSE_BARCODE_SHARED_API System::SharedPtr<Address> get_Debtor() const;
    ASPOSE_BARCODE_SHARED_API void set_Debtor(System::SharedPtr<Address> value);
    ASPOSE_BARCODE_SHARED_API System::String get_UnstructuredMessage() const;
    ASPOSE_BARCODE_SHARED_API void set_UnstructuredMessage(System::String value);
    ASPOSE_BARCODE_SHARED_API System::String get_BillInformation() const;
    ASPOSE_BARCODE_SHARED_API void set_BillInformation(System::String value);
    ASPOSE_BARCODE_SHARED_API System::SharedPtr<System::Collections::Generic::List<System::SharedPtr<AlternativeScheme>>> get_AlternativeSchemes() const;
    ASPOSE_BARCODE_SHARED_API void set_AlternativeSchemes(System::SharedPtr<System::Collections::Generic::List<System::SharedPtr<AlternativeScheme>>> value);
    
    ASPOSE_BARCODE_SHARED_API void CreateAndSetCreditorReference(System::String rawReference);
    ASPOSE_BARCODE_SHARED_API bool Equals(System::SharedPtr<System::Object> obj) override;
    ASPOSE_BARCODE_SHARED_API bool Equals(System::SharedPtr<SwissQRBill> other) override;
    ASPOSE_BARCODE_SHARED_API int32_t GetHashCode() const override;
    
protected:

    SwissQRBill();
    
    MEMBER_FUNCTION_MAKE_OBJECT_DECLARATION(SwissQRBill, CODEPORTING_ARGS());
    #ifdef ASPOSE_GET_SHARED_MEMBERS
    ASPOSE_BARCODE_SHARED_API void GetSharedMembers(System::Object::shared_members_type& result) const override;
    #endif
    
    
private:

    SwissQRBill::QrBillStandardVersion pr_Version;
    System::Decimal pr_Amount;
    System::String pr_Currency;
    System::String pr_Account;
    System::SharedPtr<Address> pr_Creditor;
    System::String pr_Reference;
    System::SharedPtr<Address> pr_Debtor;
    System::String pr_UnstructuredMessage;
    System::String pr_BillInformation;
    System::SharedPtr<System::Collections::Generic::List<System::SharedPtr<AlternativeScheme>>> pr_AlternativeSchemes;
    
    template <typename T>
    static bool SequenceEqual(System::SharedPtr<System::Collections::Generic::List<T>> list1, System::SharedPtr<System::Collections::Generic::List<T>> list2)
    {
        if (list1 == list2)
        {
            return true;
        }
        
        if (list1 == nullptr || list2 == nullptr)
        {
            return false;
        }
        
        if (list1->get_Count() != list2->get_Count())
        {
            return false;
        }
        
        for (int32_t i = 0; i < list1->get_Count(); i++)
        {
            if (!System::ObjectExt::Equals(list1->idx_get(i), list2->idx_get(i)))
            {
                return false;
            }
        }
        
        return true;
    }
    
    
};

class Payments
{
    typedef Payments ThisType;
    
public:

    class ASPOSE_BARCODE_SHARED_CLASS CleaningResult : public System::Object, public System::Details::BoxableObjectBase
    {
        typedef CleaningResult ThisType;
        typedef System::Object BaseType;
        
        typedef ::System::BaseTypesInfo<BaseType> ThisTypeBaseTypesInfo;
        ASPOSE_BARCODE_SHARED_RTTI_INFO_DECL();
        
    public:
    
        ASPOSE_BARCODE_SHARED_API System::String get_CleanedString() const;
        ASPOSE_BARCODE_SHARED_API void set_CleanedString(System::String value);
        ASPOSE_BARCODE_SHARED_API bool get_ReplacedUnsupportedChars() const;
        ASPOSE_BARCODE_SHARED_API void set_ReplacedUnsupportedChars(bool value);
        
        ASPOSE_BARCODE_SHARED_API CleaningResult();
        
    private:
    
        System::String pr_CleanedString;
        bool pr_ReplacedUnsupportedChars;
        
    };
    
    
public:

    static void CleanValue(System::String value, Payments::CleaningResult& result);
    static bool IsValidIban(System::String iban);
    static System::String FormatIban(System::String iban);
    static bool IsValidIso11649Reference(System::String reference);
    static System::String CreateIso11649Reference(System::String rawReference);
    static bool IsValidQrReference(System::String reference);
    static System::String FormatQrReferenceNumber(System::String refNo);
    static bool IsAlphaNumeric(System::String value);
    
private:

    static System::ArrayPtr<int32_t> Mod10;
    
    static System::String WhiteSpaceRemoved(System::String value);
    static void CleanValue(System::String value, Payments::CleaningResult& result, bool isNormalized);
    static bool HasValidMod97CheckDigits(System::String number);
    static int32_t CalculateMod97(System::String reference);
    static bool IsNumeric(System::String value);
    static bool IsValidQrBillCharacter(char16_t ch);
    
    static struct __StaticConstructor__ { __StaticConstructor__(); } s_constructor__;
    
public:
    Payments() = delete;
};

class ASPOSE_BARCODE_SHARED_CLASS AlternativeScheme final : public System::IEquatable<System::SharedPtr<Aspose::BarCode::ComplexBarcode::AlternativeScheme>>
{
    typedef AlternativeScheme ThisType;
    typedef System::IEquatable<System::SharedPtr<Aspose::BarCode::ComplexBarcode::AlternativeScheme>> BaseType;
    
    typedef ::System::BaseTypesInfo<BaseType> ThisTypeBaseTypesInfo;
    ASPOSE_BARCODE_SHARED_RTTI_INFO_DECL();
    
public:

    ASPOSE_BARCODE_SHARED_API System::String get_Instruction() const;
    ASPOSE_BARCODE_SHARED_API void set_Instruction(System::String value);
    
    ASPOSE_BARCODE_SHARED_API bool Equals(System::SharedPtr<System::Object> obj) override;
    ASPOSE_BARCODE_SHARED_API bool Equals(System::SharedPtr<AlternativeScheme> other) override;
    ASPOSE_BARCODE_SHARED_API int32_t GetHashCode() const override;
    
private:

    System::String pr_Instruction;
    
};

enum class AddressType
{
    Undetermined,
    Structured,
    CombinedElements,
    Conflicting
};

class ASPOSE_BARCODE_SHARED_CLASS Address final : public System::IEquatable<System::SharedPtr<Aspose::BarCode::ComplexBarcode::Address>>
{
    typedef Address ThisType;
    typedef System::IEquatable<System::SharedPtr<Aspose::BarCode::ComplexBarcode::Address>> BaseType;
    
    typedef ::System::BaseTypesInfo<BaseType> ThisTypeBaseTypesInfo;
    ASPOSE_BARCODE_SHARED_RTTI_INFO_DECL();
    
    friend class Aspose::BarCode::ComplexBarcode::SwissQRCodetext;
    
public:

    ASPOSE_BARCODE_SHARED_API AddressType get_Type() const;
    ASPOSE_BARCODE_SHARED_API System::String get_Name() const;
    ASPOSE_BARCODE_SHARED_API void set_Name(System::String value);
    ASPOSE_BARCODE_SHARED_API System::String get_AddressLine1() const;
    ASPOSE_BARCODE_SHARED_API void set_AddressLine1(System::String value);
    ASPOSE_BARCODE_SHARED_API System::String get_AddressLine2() const;
    ASPOSE_BARCODE_SHARED_API void set_AddressLine2(System::String value);
    ASPOSE_BARCODE_SHARED_API System::String get_Street() const;
    ASPOSE_BARCODE_SHARED_API void set_Street(System::String value);
    ASPOSE_BARCODE_SHARED_API System::String get_HouseNo() const;
    ASPOSE_BARCODE_SHARED_API void set_HouseNo(System::String value);
    ASPOSE_BARCODE_SHARED_API System::String get_PostalCode() const;
    ASPOSE_BARCODE_SHARED_API void set_PostalCode(System::String value);
    ASPOSE_BARCODE_SHARED_API System::String get_Town() const;
    ASPOSE_BARCODE_SHARED_API void set_Town(System::String value);
    ASPOSE_BARCODE_SHARED_API System::String get_CountryCode() const;
    ASPOSE_BARCODE_SHARED_API void set_CountryCode(System::String value);
    
    ASPOSE_BARCODE_SHARED_API Address();
    
    ASPOSE_BARCODE_SHARED_API void Clear();
    ASPOSE_BARCODE_SHARED_API bool Equals(System::SharedPtr<System::Object> obj) override;
    ASPOSE_BARCODE_SHARED_API bool Equals(System::SharedPtr<Address> other) override;
    ASPOSE_BARCODE_SHARED_API int32_t GetHashCode() const override;
    
protected:

    bool IsEmpty();
    #ifdef ASPOSE_GET_SHARED_MEMBERS
    ASPOSE_BARCODE_SHARED_API void GetSharedMembers(System::Object::shared_members_type& result) const override;
    #endif
    
    
private:

    static System::SharedPtr<Address> EmptyAddress;
    AddressType pr_Type;
    
    ASPOSE_BARCODE_SHARED_API void set_Type(AddressType value);
    
    System::String pr_Name;
    System::String _addressLine1;
    System::String _addressLine2;
    System::String _street;
    System::String _houseNo;
    System::String _postalCode;
    System::String _town;
    System::String pr_CountryCode;
    
    void ChangeType(AddressType desiredType);
    
};

} // namespace ComplexBarcode
} // namespace BarCode
} // namespace Aspose

template<>
struct EnumMetaInfo<Aspose::BarCode::ComplexBarcode::SwissQRBill::QrBillStandardVersion>
{
    static const ASPOSE_BARCODE_SHARED_API std::array<std::pair<Aspose::BarCode::ComplexBarcode::SwissQRBill::QrBillStandardVersion, const char_t*>, 1>& values();
};
template<>
struct EnumMetaInfo<Aspose::BarCode::ComplexBarcode::AddressType>
{
    static const ASPOSE_BARCODE_SHARED_API std::array<std::pair<Aspose::BarCode::ComplexBarcode::AddressType, const char_t*>, 4>& values();
};



